@@ -46,23 +46,19 @@ extern SbkConverter **SbkPySide6_QtUiToolsTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTUITOOLS_QLIST_INT_IDX                              = 0, // QList<int>
-    SBK_QTUITOOLS_QLIST_QOBJECTPTR_IDX                       = 2, // QList<QObject*>
-    SBK_QTUITOOLS_QLIST_QBYTEARRAY_IDX                       = 4, // QList<QByteArray>
-    SBK_QTUITOOLS_QLIST_QVARIANT_IDX                         = 6, // QList<QVariant>
-    SBK_QTUITOOLS_QLIST_QSTRING_IDX                          = 8, // QList<QString>
-    SBK_QTUITOOLS_QMAP_QSTRING_QVARIANT_IDX                  = 10, // QMap<QString,QVariant>
-    SBK_QTUITOOLS_CONVERTERS_IDX_COUNT                       = 12,
+    SBK_QTUITOOLS_QLIST_QVARIANT_IDX                         = 1, // QList<QVariant>
+    SBK_QTUITOOLS_QLIST_QSTRING_IDX                          = 2, // QList<QString>
+    SBK_QTUITOOLS_QMAP_QSTRING_QVARIANT_IDX                  = 3, // QMap<QString,QVariant>
+    SBK_QTUITOOLS_CONVERTERS_IDX_COUNT                       = 4,
 };
 
 // Converter indices
 enum : int {
     SBK_QtUiTools_QList_int_IDX                              = 0, // QList<int>
-    SBK_QtUiTools_QList_QObjectPTR_IDX                       = 1, // QList<QObject*>
-    SBK_QtUiTools_QList_QByteArray_IDX                       = 2, // QList<QByteArray>
-    SBK_QtUiTools_QList_QVariant_IDX                         = 3, // QList<QVariant>
-    SBK_QtUiTools_QList_QString_IDX                          = 4, // QList<QString>
-    SBK_QtUiTools_QMap_QString_QVariant_IDX                  = 5, // QMap<QString,QVariant>
-    SBK_QtUiTools_CONVERTERS_IDX_COUNT                       = 6,
+    SBK_QtUiTools_QList_QVariant_IDX                         = 1, // QList<QVariant>
+    SBK_QtUiTools_QList_QString_IDX                          = 2, // QList<QString>
+    SBK_QtUiTools_QMap_QString_QVariant_IDX                  = 3, // QMap<QString,QVariant>
+    SBK_QtUiTools_CONVERTERS_IDX_COUNT                       = 4,
 };
 // Macros for type check
 
